#include <Servo.h>
#include <Bounce2.h>
#include <SoftwareSerial.h>

const int up = 14;
const int down = 15;
const int left = 16; 
const int right = 17;
const int mid = 18;
const int laserControl = 3;   // the number of the pin connected to the transistor controlling the laser
const int ledPin = 13;

int panservoval = 96;
int tiltservoval = 88;
int addsubtractval = 1;
int bluetoothdelay = 150;
int servodelay = 150;
int laserState;

char incomingByte; // variable to receive data from the serial port

Bounce updebounce = Bounce();
Bounce downdebounce = Bounce();
Bounce leftdebounce = Bounce();
Bounce rightdebounce = Bounce();
Bounce middebounce = Bounce();

SoftwareSerial BTSerial(7, 6); // RX | TX

Servo panservo;  // create servo object to control a servo
Servo tiltservo;

void setup(){
  BTSerial.begin(9600);
  panservo.attach(9);  // attaches the servo on pin 9 to the servo object
  tiltservo.attach(10);
  panservo.write(panservoval);   // sets the servo position according to the scaled value
  tiltservo.write(tiltservoval);
  delay(250);
  pinMode(laserControl, OUTPUT);
  pinMode(ledPin,OUTPUT);
  pinMode(up, INPUT_PULLUP);
  pinMode(down, INPUT_PULLUP);
  pinMode(left, INPUT_PULLUP);
  pinMode(right, INPUT_PULLUP);
  pinMode(mid, INPUT_PULLUP);
  updebounce.attach(up);
  updebounce.interval(50); // interval in ms
  downdebounce.attach(down);
  downdebounce.interval(50); // interval in ms
  leftdebounce.attach(left);
  leftdebounce.interval(50); // interval in ms
  rightdebounce.attach(right);
  rightdebounce.interval(50); // interval in ms
  middebounce.attach(mid);
  middebounce.interval(50); // interval in ms
  digitalWrite(laserControl, HIGH);
  laserState = 1;
}
void loop(){
  if(BTSerial.available() != 0 ){
    incomingByte = 0;
    incomingByte = BTSerial.read(); // read it and store it in 'incomingByte'
    delay(bluetoothdelay);
    if(incomingByte == 'u'){
      tiltservoval = tiltservoval - addsubtractval;
      delay(bluetoothdelay);
      incomingByte = 0;
    } 
    else if(incomingByte == 'd'){
      tiltservoval = tiltservoval + addsubtractval;
      delay(bluetoothdelay);
      incomingByte = 0;
    }
    else if(incomingByte == 'l'){
      panservoval = panservoval + addsubtractval;
      delay(bluetoothdelay);
      incomingByte = 0;
    } 
    else if(incomingByte == 'r'){
      panservoval = panservoval - addsubtractval;
      delay(bluetoothdelay);
      incomingByte = 0;
    }
    else if(incomingByte == 'm'){
      panservoval = 96;
      tiltservoval = 88;
      delay(100);
      incomingByte = 0;
    }
    else if(incomingByte == 'o'){
      if(laserState == 1){
        digitalWrite(laserControl, LOW);
        laserState = 0;
      }
      else if(laserState == 0){
        digitalWrite(laserControl, HIGH);
        laserState = 1;
      }
    }
  }
  updebounce.update();
  downdebounce.update();
  leftdebounce.update();
  rightdebounce.update();
  middebounce.update();

  int upvalue = updebounce.read();
  int downvalue = downdebounce.read();
  int leftvalue = leftdebounce.read();
  int rightvalue = rightdebounce.read();
  int midvalue = middebounce.read();

  if(upvalue == LOW){
    tiltservoval = tiltservoval - addsubtractval;
    delay(servodelay);
  } 
  else if(downvalue == LOW){
    tiltservoval = tiltservoval + addsubtractval;
    delay(servodelay);
  }
  if(leftvalue == LOW){
    panservoval = panservoval + addsubtractval;
    delay(servodelay);
  } 
  else if(rightvalue == LOW){
    panservoval = panservoval - addsubtractval;
    delay(servodelay);
  }
  if(midvalue == LOW){
    panservoval = 96;
    tiltservoval = 88;
    delay(100);
  }
  if (panservoval > 179){
    panservoval = 179;
  }
  if (panservoval < 0){
    panservoval = 0;
  }
  if (tiltservoval > 115){
    tiltservoval = 115;
  }
  if (tiltservoval < 0){
    tiltservoval = 0;
  }
  panservo.write(panservoval);   // sets the servo position according to the scaled value
  tiltservo.write(tiltservoval);
}



















